@@ -50,20 +50,22 @@ def throw(message):
 #------------------------------------------------------------------------
 
 def checkError():
-    lastcall = restClient.lastCall()
-    response = lastcall['response']
-    if 'messages' in response:
-        if len(response['messages']) > 0:
-            msg = response['messages'][0]
-            if 'code' in msg:
-                if msg['code'] == '208' or msg['code'] == '101':
-                    return False
+    lc = restClient.lastCall()
+    if lc['error'] is not None:
+      utils.raiseException(lc['errorCode'],lc['error'],lc['action'])
+ #   response = lastcall['response']
+ #   if 'messages' in response:
+ #       if len(response['messages']) > 0:
+ #           msg = response['messages'][0]
+ #           if 'code' in msg:
+ #               if msg['code'] == '208' or msg['code'] == '101':
+ #                   return False
+#
+#                if msg['severity'] == 'ERROR':
+#                    return throw(msg)
 
-                if msg['severity'] == 'ERROR':
-                    return throw(msg)
-
-    elif lastcall['status_code'] == 600:
-        return throw(response)
+ #   elif lastcall['status_code'] == 600:
+ #       return throw(response)
 
     return False
 
