@@ -1,10 +1,11 @@
 from . import restClient,query,digitalCommerceUtil,file,utils,objectUtil
 import simplejson,logging
 
-def queryLogRecords(logUserId=None,limit=50):
-    whereUSer = f" where logUserId='{logUserId}' " if logUserId is not None else ''
+def _queryLogRecords(logUserId=None,limit=50,whereClause=None):
+    where = f" where {whereClause} " if whereClause != None else ''
+    where = f" where logUserId='{logUserId}' " if logUserId is not None else where
 
-    call = query.query(f"Select Id,LogUserId,LogLength,LastModifiedDate,Request,Operation,Application,Status,DurationMilliseconds,StartTime,Location,RequestIdentifier FROM ApexLog  {whereUSer} order by LastModifiedDate desc limit {limit}")
+    call = query.query(f"Select Id,LogUserId,LogLength,LastModifiedDate,Request,Operation,Application,Status,DurationMilliseconds,StartTime,Location,RequestIdentifier FROM ApexLog  {where} order by LastModifiedDate desc limit {limit}")
     return call
 
 def queryLogData(logId):
@@ -23,7 +24,7 @@ LOGDATA:    app: {log['Application']}      status: {log['Status']}     location:
     callbody = logLine + callbody
     return log,callbody
 
-def parseLog(logId=None,filepath=None,printLimits=True,userDebug=True,lastN=1,logUserId=None,level=None):
+def parseLog(logId=None,filepath=None,printLimits=True,userDebug=True,lastN=1,logUserId=None,level=None,whereClause=None):
     body = None
 
     if filepath != None:
@@ -37,13 +38,15 @@ def parseLog(logId=None,filepath=None,printLimits=True,userDebug=True,lastN=1,lo
            logRecord,body = queryLogData(logId) 
 
     else:
-        whereUSer = f" where logUserId='{logUserId}' " if logUserId is not None else ''
-        logIds = query.queryFieldList(f"Select Id FROM ApexLog {whereUSer} order by LastModifiedDate desc limit {lastN}")
+        where = f" where {whereClause} " if whereClause is not None else ''
+        where = f" where logUserId='{logUserId}' " if logUserId is not None else where
+
+        logIds = query.queryFieldList(f"Select Id FROM ApexLog {where} order by LastModifiedDate desc limit {lastN}")
         if logIds == None or len(logIds)==0:
             utils.raiseException(errorCode='NO_LOG',error=f'No logs can be found. ')
         for logId in logIds:
             print('___________________________________________________________________________________________________________________________________________________________________')
-            print(f"Parsing log Id {logId}")
+          #  print(f"Parsing log Id {logId}    file:{restClient.logFolder()}{logId}.log")
             parseLog(logId)
         #    input("Click for next")
         return  
@@ -54,11 +57,12 @@ def parseLog(logId=None,filepath=None,printLimits=True,userDebug=True,lastN=1,lo
     if filepath == None:
         filename = f"{restClient.logFolder()}{logId}.log"
         file.write(filename,body)
+    print(f"Parsing log Id {logId}    file:{restClient.logFolder()}{logId}.log")
 
     return parse(body,printLimits=printLimits,userDebug=userDebug,level=level)
 
-def printLogs(logUserId=None,limit=50):
-    logs = queryLogRecords(logUserId,limit=limit)
+def printLogs(logUserId=None,limit=50,whereClause=None):
+    logs = _queryLogRecords(logUserId,limit=limit,whereClause=whereClause)
     logs = utils.deleteNulls(logs,systemFields=False)
     utils.printFormated(logs,rename="LogLength%Len:DurationMilliseconds%ms")
 
@@ -159,11 +163,11 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
     constructorList = onGoingCalls
     dmlList=onGoingCalls
 
-   # methodsList = []
-   # constructorList = []
-   # codeUnitsList = []
-   # constructorList = []
-   # dmlList=[]
+    methodsList = []
+    constructorList = []
+    codeUnitsList = []
+    constructorList = []
+    dmlList=[]
 
     limits = None
 
@@ -179,6 +183,10 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
     print()
 
     for num,line in enumerate(lines):
+  #      print(num)
+ #       if num == 282:
+ #           print()
+
         chunks = line.split('|')
 
         if _context['firstLineIn'] == True:
@@ -250,7 +258,7 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
                     debugList.append(obj)
                     obj['output'] = obj['string'] 
 
-            _context['EXP_VAR'] = True
+                    _context['EXP_VAR'] = True
  
         if '|LIMIT_USAGE|' in line:
             if '|SOQL|' in line:
@@ -338,7 +346,7 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
 
         if '|WF_RULE_EVAL' in line:
             if 'BEGIN' in chunks[1]:
-                workflow = setTimes(line,field='method',value=chunks[2])
+                workflow = setTimes(line,field='method',value=chunks[2],type='RULE_EVAL')
 
             if 'END' in chunks[1]:
                 setTimes(line,workflow)
@@ -427,6 +435,7 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
                 obj = setTimes(line,type='METHOD')
                 obj['method'] = method
                 obj['apexline'] = chunks[2][1:-1] if chunks[2]!='[EXTERNAL]' else 'EX'
+                obj['output'] = obj['method']
                 debugList.append(obj)
 
                 if '.getInstance' in method:
@@ -437,7 +446,7 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
             else:
                 obj = delFromList(methodsList,'method',method)
                 if obj == None:
-                    obj = delFromList(methodsList,'method',f".{method}",endsWith=True)
+                    obj = delFromList(methodsList,'method',f"{method}",endsWith=True)
 
                 if obj is not None:
                     decreaseIdent()
@@ -447,7 +456,10 @@ def parse(logData,printLimits=True,userDebug=True,level=None):
                     obj = setTimes(line,type='NO_ENTRY')
                     debugList.append(obj)
 
-                obj['output']=obj['method']
+                if 'method' in obj:
+                    obj['output']=obj['method']
+                else:
+                    obj['output']=obj['Id']
 
     repDebugList = processRepetition(debugList)
     printDebugList(repDebugList)
@@ -481,6 +493,9 @@ def processRepetition(debugList):
 
       return False,None
 
+    for deb in debugList:
+        if 'output' not in deb:
+            print()
     repss = utils.repeatingSequence(debugList,"output")
 
     parsedX = []
@@ -679,10 +694,10 @@ def printParsedLog(d):
         print(f"{i:15} {ms(d['elapsedTime']):10}|{_elapsedPrevD:8}|{d['timeStamp'][0]:12}|{_timeStamp1:12}|{ms(delta(d,'timeStamp')):10}|{_totalQueriesTrace:15}|{_totalQueriesD:4}|{_totalQueries1:4}|{_plimit:1}|{_cpuPrevD:6}|{_cpuTime0:6}|{_cpuTime1:6}|{_sql2:3}|{_sqlcmt2:3}|{_typeColor}{_type:12}{CEND}|{_exp:1}|{_apexline:>4}|{val[:150]:50}"+CEND)
     else:
         if _context['firstLineOut'] == True:
-            print(f"{' ':15}|{'time(ms)':10}|{'elapsed':10}|{'time1(ns)':12}|{'time2(ns)':12}|{'t2-t1':10}|{'Qd':4}|{'Qt':4}|{'L':1}|{'cpuD':6}|{'CPUin':6}|{'Q':3}|{'Qcm':3}|{'type':12}|{'E':1}|{'al':4}{'':50}")
+            print(f"{'time(ms)':10}|{'elapsed':10}|{'time1(ns)':12}|{'time2(ns)':12}|{'t2-t1':10}|{'Qd':4}|{'Qt':4}|{'L':1}|{'cpuD':6}|{'CPUin':6}|{'Q':3}|{'Qcm':3}|{'type':12}|{'E':1}|{'al':4}{'':50}")
             _context['firstLineOut'] = False
 
-        print(f"{'':15} {ms(d['elapsedTime']):10}|{_elapsedPrevD:8}|{d['timeStamp'][0]:12}|{_timeStamp1:12}|{ms(delta(d,'timeStamp')):10}|{_totalQueriesD:4}|{_totalQueries1:4}|{_plimit:1}|{_cpuPrevD:6}|{_cpuTime0:6}|{_sql2:3}|{_sqlcmt2:3}|{_typeColor}{_type:12}{CEND}|{_exp:1}|{_apexline:>4}|{val[:150]:50}"+CEND)
+        print(f"{ms(d['elapsedTime']):10}|{_elapsedPrevD:8}|{d['timeStamp'][0]:12}|{_timeStamp1:12}|{ms(delta(d,'timeStamp')):10}|{_totalQueriesD:4}|{_totalQueries1:4}|{_plimit:1}|{_cpuPrevD:6}|{_cpuTime0:6}|{_sql2:3}|{_sqlcmt2:3}|{_typeColor}{_type:12}{CEND}|{_exp:1}|{_apexline:>4}|{val[:150]:50}"+CEND)
 
 logsList = []
 def ms(val):
@@ -699,7 +714,7 @@ def delFromList(theList,field,value,endsWith=False):
         for i,obj in enumerate(theList):
             if field in obj:
                 if endsWith == True:
-                    if obj[field].endswith(value):
+                    if obj[field].endswith(value) or obj[field].startswith(value):
                         theList.pop(i)
                         return obj    
                 else:
