@@ -27,6 +27,7 @@ CLIGHT_BLUE = "\033[1;34m"
 CLIGHT_PURPLE = "\033[1;35m"
 CLIGHT_CYAN = "\033[1;36m"
 CLIGHT_WHITE = "\033[1;37m"
+CWHITE = '\33[37m'
 CBOLD = "\033[1m"
 CFAINT = "\033[2m"
 CITALIC = "\033[3m"
@@ -35,6 +36,10 @@ CBLINK = "\033[5m"
 CNEGATIVE = "\033[7m"
 CCROSSED = "\033[9m"
 CEND = "\033[0m"
+
+CBGBLUE = "\033[104m"
+
+#https://stackoverflow.com/questions/287871/how-do-i-print-colored-text-to-the-terminal
 #----------------------------------------------------------------------------------------------------
 def stringifyUrlParameters(parameters,exclude,initSeparator='?'):
   isFirst = True
@@ -234,6 +239,8 @@ def printFormated(records,fieldsString=None,rename=None,exclude=None):
         for ren in renames:
             chunks = ren.split('%')
             _renames[chunks[0]] = chunks[1]
+            print( CFAINT +  f"Column {chunks[0]} as {chunks[1]}" +CEND)
+        print()
     
     _fields = {}
     for field in fields:
@@ -260,21 +267,21 @@ def printFormated(records,fieldsString=None,rename=None,exclude=None):
         field = _fields[key]        
         value = field['print_name']
 
-        line = f"{line}{value:{int(field['size']+spacing)}}"
-    print(line)
+        line =  f"{line}{value:{int(field['size']+spacing)}}" 
+    print(CUNDERLINE+line+CEND)
 
     for record in records:
         line = ''
         for key in _fields.keys():
             field = _fields[key]    
 
-            if field == "__color__":
+            if key == "__color__":
                 continue
 
             val = objectUtil.getField(record,key,'.')
             val = '' if val is None else str(val) 
             padding = int(field['size']+spacing)
-          #  val = str(record[key]) if key in record else ''
+ #           print(f"{padding}  {field['size']}")
             if _isInt(val):
                 line = f"{line}{int(val):>{padding-1}} "
             elif _isFloat(val):
@@ -454,6 +461,7 @@ def repeatingSequence(objs,field):
         positions = []
 
         for y in range(x+1,len(objs)):
+
             if field not in objs[y]:
                 _o = objs[y]
                 print()
@@ -469,6 +477,7 @@ def repeatingSequence(objs,field):
                 if lastDelta == firstdelta:
                     for z in range(0,firstdelta):
                         if y+z >= len(objs):
+                            seq=False
                             break
                         if objs[y+z][field] != objs[x+z][field]:
                             seq = False
