@@ -1,5 +1,5 @@
 from InCli.SFAPI import utils
-
+import sys, os
 #python3 -m unittest
 
 import unittest
@@ -32,19 +32,43 @@ class Test_Main(unittest.TestCase):
     def test_h(self):
         InCli._main(["-h"])
 
-    def test_check_Catalog(self):
+    def test_cc(self):
         try:
             InCli._main(["-u","NOSQSM","-cc"])
         except Exception as e:
             utils.printException(e)
             print()
 
+    def test_cc_list(self):
+        try:
+            InCli._main(["-u","NOSDEV","-cc","-list"])
+        except Exception as e:
+            utils.printException(e)
+            print()
+
+    def test_cc_code(self):
+        try:
+            InCli._main(["-u","NOSDEV","-cc","-code","TESTERRORS"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+
+    def test_cc_account(self):
+        try:
+            InCli._main(["-u","NOSDEV","-cc","-account","name:unaiTest4","-code","TESTERRORS"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+
     def test_logs(self):
         InCli._main(["-u","NOSDEV","-logs"])
 
     def test_logs_user(self):
         InCli._main(["-u","NOSDEV","-logs","-loguser","Alias:ana.r"])
 
+    def test_logs_query(self):
+        InCli._main(["-u","NOSDEV","-logs","-where","Operation='Batch Apex'","-last","10"])
+
     def test_logs_userDefault(self):
         InCli._main(["-default:set","loguser","Alias:ana.r"])
         InCli._main(["-u","NOSDEV","-logs"])
@@ -62,13 +86,19 @@ class Test_Main(unittest.TestCase):
 
     def test_logs(self):
         InCli._main(["-u","NOSDEV","-logs"])
-
-    def test_log_ID(self):
+   
+    def test_log_ID_2(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","07L3O00000DgHUZUA3"])
+            InCli._main(["-u","NOSDEV","-logs","07L3O00000DgMVOUA3"])
         except Exception as e:
             print(e)
-            traceback.format_exc()
+            print(traceback.format_exc())
+    def test_log_ID(self):
+        try:
+            InCli._main(["-u","NOSDEV","-logs","07L3O00000DgMguUAF"])
+        except Exception as e:
+            print(e)
+            print(traceback.format_exc())
     def test_log_file(self):
         InCli._main(["-u","NOSDEV","-logs","07L3O00000DfytZUAR","-level","0"])
 
